'''_2232.py

CylindricalGear
'''


from typing import List, Optional

from mastapy._internal import constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.gears.gear_designs.cylindrical import _950, _977
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.connections_and_sockets.gears import _2018
from mastapy.system_model.part_model.gears import _2237
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Gears', 'CylindricalGear')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGear',)


class CylindricalGear(_2237.Gear):
    '''CylindricalGear

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGear.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def has_concept_synchroniser(self) -> 'bool':
        '''bool: 'HasConceptSynchroniser' is the original name of this property.'''

        return self.wrapped.HasConceptSynchroniser

    @has_concept_synchroniser.setter
    def has_concept_synchroniser(self, value: 'bool'):
        self.wrapped.HasConceptSynchroniser = bool(value) if value else False

    @property
    def estimated_crowning(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'EstimatedCrowning' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.EstimatedCrowning) if self.wrapped.EstimatedCrowning else None

    @estimated_crowning.setter
    def estimated_crowning(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.EstimatedCrowning = value

    @property
    def centre_of_estimated_micro_geometry_range(self) -> 'float':
        '''float: 'CentreOfEstimatedMicroGeometryRange' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CentreOfEstimatedMicroGeometryRange

    @property
    def left_limit_of_estimated_micro_geometry_range(self) -> 'float':
        '''float: 'LeftLimitOfEstimatedMicroGeometryRange' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LeftLimitOfEstimatedMicroGeometryRange

    @property
    def right_limit_of_estimated_micro_geometry_range(self) -> 'float':
        '''float: 'RightLimitOfEstimatedMicroGeometryRange' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RightLimitOfEstimatedMicroGeometryRange

    @property
    def linear_relief(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'LinearRelief' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.LinearRelief) if self.wrapped.LinearRelief else None

    @linear_relief.setter
    def linear_relief(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.LinearRelief = value

    @property
    def extra_backlash(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'ExtraBacklash' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.ExtraBacklash) if self.wrapped.ExtraBacklash else None

    @extra_backlash.setter
    def extra_backlash(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.ExtraBacklash = value

    @property
    def clocking_angle_error(self) -> 'float':
        '''float: 'ClockingAngleError' is the original name of this property.'''

        return self.wrapped.ClockingAngleError

    @clocking_angle_error.setter
    def clocking_angle_error(self, value: 'float'):
        self.wrapped.ClockingAngleError = float(value) if value else 0.0

    @property
    def reference_axis_angle_about_local_z_axis_from_y_axis(self) -> 'float':
        '''float: 'ReferenceAxisAngleAboutLocalZAxisFromYAxis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ReferenceAxisAngleAboutLocalZAxisFromYAxis

    @property
    def maximum_tip_diameter(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MaximumTipDiameter' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MaximumTipDiameter) if self.wrapped.MaximumTipDiameter else None

    @maximum_tip_diameter.setter
    def maximum_tip_diameter(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.MaximumTipDiameter = value

    @property
    def clearance_to_maximum_tip_diameter(self) -> 'float':
        '''float: 'ClearanceToMaximumTipDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ClearanceToMaximumTipDiameter

    @property
    def minimum_root_diameter(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MinimumRootDiameter' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MinimumRootDiameter) if self.wrapped.MinimumRootDiameter else None

    @minimum_root_diameter.setter
    def minimum_root_diameter(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.MinimumRootDiameter = value

    @property
    def is_position_fixed_for_centre_distance_modification(self) -> 'bool':
        '''bool: 'IsPositionFixedForCentreDistanceModification' is the original name of this property.'''

        return self.wrapped.IsPositionFixedForCentreDistanceModification

    @is_position_fixed_for_centre_distance_modification.setter
    def is_position_fixed_for_centre_distance_modification(self, value: 'bool'):
        self.wrapped.IsPositionFixedForCentreDistanceModification = bool(value) if value else False

    @property
    def active_gear_design(self) -> '_950.CylindricalGearDesign':
        '''CylindricalGearDesign: 'ActiveGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _950.CylindricalGearDesign.TYPE not in self.wrapped.ActiveGearDesign.__class__.__mro__:
            raise CastException('Failed to cast active_gear_design to CylindricalGearDesign. Expected: {}.'.format(self.wrapped.ActiveGearDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ActiveGearDesign.__class__)(self.wrapped.ActiveGearDesign) if self.wrapped.ActiveGearDesign else None

    @property
    def cylindrical_gear_design(self) -> '_950.CylindricalGearDesign':
        '''CylindricalGearDesign: 'CylindricalGearDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _950.CylindricalGearDesign.TYPE not in self.wrapped.CylindricalGearDesign.__class__.__mro__:
            raise CastException('Failed to cast cylindrical_gear_design to CylindricalGearDesign. Expected: {}.'.format(self.wrapped.CylindricalGearDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.CylindricalGearDesign.__class__)(self.wrapped.CylindricalGearDesign) if self.wrapped.CylindricalGearDesign else None

    @property
    def cylindrical_meshes(self) -> 'List[_2018.CylindricalGearMesh]':
        '''List[CylindricalGearMesh]: 'CylindricalMeshes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CylindricalMeshes, constructor.new(_2018.CylindricalGearMesh))
        return value

    def make_carrier_assembly(self, number_of_radial_bearings: 'int', add_left_thrust_bearing: 'bool', add_right_thrust_bearing: 'bool', gear_bore: 'float', carrier_bore: 'float', carrier_width: 'float', gear_offset: Optional['float'] = 0.0, left_bearing_indent: Optional['float'] = 0.0, right_bearing_indent: Optional['float'] = 0.0, thrust_pad_clearance: Optional['float'] = 0.0, adding_bearing: Optional['bool'] = True, left_thurst_pad_contact_diameter: Optional['float'] = None, right_thurst_pad_contact_diameter: Optional['float'] = None):
        ''' 'MakeCarrierAssembly' is the original name of this method.

        Args:
            number_of_radial_bearings (int)
            add_left_thrust_bearing (bool)
            add_right_thrust_bearing (bool)
            gear_bore (float)
            carrier_bore (float)
            carrier_width (float)
            gear_offset (float, optional)
            left_bearing_indent (float, optional)
            right_bearing_indent (float, optional)
            thrust_pad_clearance (float, optional)
            adding_bearing (bool, optional)
            left_thurst_pad_contact_diameter (float, optional)
            right_thurst_pad_contact_diameter (float, optional)
        '''

        number_of_radial_bearings = int(number_of_radial_bearings)
        add_left_thrust_bearing = bool(add_left_thrust_bearing)
        add_right_thrust_bearing = bool(add_right_thrust_bearing)
        gear_bore = float(gear_bore)
        carrier_bore = float(carrier_bore)
        carrier_width = float(carrier_width)
        gear_offset = float(gear_offset)
        left_bearing_indent = float(left_bearing_indent)
        right_bearing_indent = float(right_bearing_indent)
        thrust_pad_clearance = float(thrust_pad_clearance)
        adding_bearing = bool(adding_bearing)
        left_thurst_pad_contact_diameter = float(left_thurst_pad_contact_diameter)
        right_thurst_pad_contact_diameter = float(right_thurst_pad_contact_diameter)
        self.wrapped.MakeCarrierAssembly(number_of_radial_bearings if number_of_radial_bearings else 0, add_left_thrust_bearing if add_left_thrust_bearing else False, add_right_thrust_bearing if add_right_thrust_bearing else False, gear_bore if gear_bore else 0.0, carrier_bore if carrier_bore else 0.0, carrier_width if carrier_width else 0.0, gear_offset if gear_offset else 0.0, left_bearing_indent if left_bearing_indent else 0.0, right_bearing_indent if right_bearing_indent else 0.0, thrust_pad_clearance if thrust_pad_clearance else 0.0, adding_bearing if adding_bearing else False, left_thurst_pad_contact_diameter if left_thurst_pad_contact_diameter else 0.0, right_thurst_pad_contact_diameter if right_thurst_pad_contact_diameter else 0.0)



'''_1885.py

SphericalRollerThrustBearing
'''


from mastapy._internal import constructor
from mastapy.bearings.bearing_designs.rolling import _1860
from mastapy._internal.python_net import python_net_import

_SPHERICAL_ROLLER_THRUST_BEARING = python_net_import('SMT.MastaAPI.Bearings.BearingDesigns.Rolling', 'SphericalRollerThrustBearing')


__docformat__ = 'restructuredtext en'
__all__ = ('SphericalRollerThrustBearing',)


class SphericalRollerThrustBearing(_1860.BarrelRollerBearing):
    '''SphericalRollerThrustBearing

    This is a mastapy class.
    '''

    TYPE = _SPHERICAL_ROLLER_THRUST_BEARING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SphericalRollerThrustBearing.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def angle_between_roller_end_and_bearing_axis(self) -> 'float':
        '''float: 'AngleBetweenRollerEndAndBearingAxis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AngleBetweenRollerEndAndBearingAxis

    @property
    def element_centre_point_diameter(self) -> 'float':
        '''float: 'ElementCentrePointDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ElementCentrePointDiameter

    @property
    def distance_to_pressure_point_from_left_face(self) -> 'float':
        '''float: 'DistanceToPressurePointFromLeftFace' is the original name of this property.'''

        return self.wrapped.DistanceToPressurePointFromLeftFace

    @distance_to_pressure_point_from_left_face.setter
    def distance_to_pressure_point_from_left_face(self, value: 'float'):
        self.wrapped.DistanceToPressurePointFromLeftFace = float(value) if value else 0.0

    @property
    def width(self) -> 'float':
        '''float: 'Width' is the original name of this property.'''

        return self.wrapped.Width

    @width.setter
    def width(self, value: 'float'):
        self.wrapped.Width = float(value) if value else 0.0



'''_2185.py

UnbalancedMass
'''


from mastapy._internal import constructor
from mastapy.system_model.part_model import _2187
from mastapy._internal.python_net import python_net_import

_UNBALANCED_MASS = python_net_import('SMT.MastaAPI.SystemModel.PartModel', 'UnbalancedMass')


__docformat__ = 'restructuredtext en'
__all__ = ('UnbalancedMass',)


class UnbalancedMass(_2187.VirtualComponent):
    '''UnbalancedMass

    This is a mastapy class.
    '''

    TYPE = _UNBALANCED_MASS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'UnbalancedMass.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def radius(self) -> 'float':
        '''float: 'Radius' is the original name of this property.'''

        return self.wrapped.Radius

    @radius.setter
    def radius(self, value: 'float'):
        self.wrapped.Radius = float(value) if value else 0.0

    @property
    def angle(self) -> 'float':
        '''float: 'Angle' is the original name of this property.'''

        return self.wrapped.Angle

    @angle.setter
    def angle(self, value: 'float'):
        self.wrapped.Angle = float(value) if value else 0.0



'''_103.py

NewmarkTransientSolver
'''


from mastapy.nodal_analysis.system_solvers import _106
from mastapy._internal.python_net import python_net_import

_NEWMARK_TRANSIENT_SOLVER = python_net_import('SMT.MastaAPI.NodalAnalysis.SystemSolvers', 'NewmarkTransientSolver')


__docformat__ = 'restructuredtext en'
__all__ = ('NewmarkTransientSolver',)


class NewmarkTransientSolver(_106.SimpleVelocityBasedStepHalvingTransientSolver):
    '''NewmarkTransientSolver

    This is a mastapy class.
    '''

    TYPE = _NEWMARK_TRANSIENT_SOLVER

    __hash__ = None

    def __init__(self, instance_to_wrap: 'NewmarkTransientSolver.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1097.py

KlingelnbergFinishingMethods
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_FINISHING_METHODS = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical', 'KlingelnbergFinishingMethods')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergFinishingMethods',)


class KlingelnbergFinishingMethods(Enum):
    '''KlingelnbergFinishingMethods

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _KLINGELNBERG_FINISHING_METHODS

    __hash__ = None

    LAPPED = 0
    SOFTCUT = 1
    HPG = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


KlingelnbergFinishingMethods.__setattr__ = __enum_setattr
KlingelnbergFinishingMethods.__delattr__ = __enum_delattr



'''_4920.py

WhineWaterfallReferenceValuesBase
'''


from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_WHINE_WATERFALL_REFERENCE_VALUES_BASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses', 'WhineWaterfallReferenceValuesBase')


__docformat__ = 'restructuredtext en'
__all__ = ('WhineWaterfallReferenceValuesBase',)


class WhineWaterfallReferenceValuesBase(_0.APIBase):
    '''WhineWaterfallReferenceValuesBase

    This is a mastapy class.
    '''

    TYPE = _WHINE_WATERFALL_REFERENCE_VALUES_BASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WhineWaterfallReferenceValuesBase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def minimum_db(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MinimumDB' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MinimumDB) if self.wrapped.MinimumDB else None

    @minimum_db.setter
    def minimum_db(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.MinimumDB = value

    @property
    def maximum_db(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MaximumDB' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MaximumDB) if self.wrapped.MaximumDB else None

    @maximum_db.setter
    def maximum_db(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.MaximumDB = value



'''_578.py

CylindricalShaperDatabase
'''


from mastapy.gears.manufacturing.cylindrical import _562
from mastapy.gears.manufacturing.cylindrical.cutters import _684
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_SHAPER_DATABASE = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical', 'CylindricalShaperDatabase')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalShaperDatabase',)


class CylindricalShaperDatabase(_562.CylindricalCutterDatabase['_684.CylindricalGearShaper']):
    '''CylindricalShaperDatabase

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_SHAPER_DATABASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalShaperDatabase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1900.py

CylindricalHousingJournalBearing
'''


from mastapy.bearings.bearing_designs.fluid_film import _1907
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_HOUSING_JOURNAL_BEARING = python_net_import('SMT.MastaAPI.Bearings.BearingDesigns.FluidFilm', 'CylindricalHousingJournalBearing')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalHousingJournalBearing',)


class CylindricalHousingJournalBearing(_1907.PlainJournalHousing):
    '''CylindricalHousingJournalBearing

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_HOUSING_JOURNAL_BEARING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalHousingJournalBearing.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_4084.py

ParametricStudyHistogram
'''


from mastapy._internal import constructor
from mastapy.utility.report import _1514
from mastapy._internal.python_net import python_net_import

_PARAMETRIC_STUDY_HISTOGRAM = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools', 'ParametricStudyHistogram')


__docformat__ = 'restructuredtext en'
__all__ = ('ParametricStudyHistogram',)


class ParametricStudyHistogram(_1514.CustomReportDefinitionItem):
    '''ParametricStudyHistogram

    This is a mastapy class.
    '''

    TYPE = _PARAMETRIC_STUDY_HISTOGRAM

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ParametricStudyHistogram.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def height(self) -> 'int':
        '''int: 'Height' is the original name of this property.'''

        return self.wrapped.Height

    @height.setter
    def height(self, value: 'int'):
        self.wrapped.Height = int(value) if value else 0

    @property
    def width(self) -> 'int':
        '''int: 'Width' is the original name of this property.'''

        return self.wrapped.Width

    @width.setter
    def width(self, value: 'int'):
        self.wrapped.Width = int(value) if value else 0

    @property
    def number_of_bins(self) -> 'int':
        '''int: 'NumberOfBins' is the original name of this property.'''

        return self.wrapped.NumberOfBins

    @number_of_bins.setter
    def number_of_bins(self, value: 'int'):
        self.wrapped.NumberOfBins = int(value) if value else 0

    @property
    def use_bin_range_for_label(self) -> 'bool':
        '''bool: 'UseBinRangeForLabel' is the original name of this property.'''

        return self.wrapped.UseBinRangeForLabel

    @use_bin_range_for_label.setter
    def use_bin_range_for_label(self, value: 'bool'):
        self.wrapped.UseBinRangeForLabel = bool(value) if value else False



'''_495.py

ConicalGearSingleFlankRating
'''


from mastapy.gears.rating import _329
from mastapy._internal.python_net import python_net_import

_CONICAL_GEAR_SINGLE_FLANK_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Conical', 'ConicalGearSingleFlankRating')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalGearSingleFlankRating',)


class ConicalGearSingleFlankRating(_329.GearSingleFlankRating):
    '''ConicalGearSingleFlankRating

    This is a mastapy class.
    '''

    TYPE = _CONICAL_GEAR_SINGLE_FLANK_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalGearSingleFlankRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1917.py

ComponentDampingOption
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_COMPONENT_DAMPING_OPTION = python_net_import('SMT.MastaAPI.SystemModel', 'ComponentDampingOption')


__docformat__ = 'restructuredtext en'
__all__ = ('ComponentDampingOption',)


class ComponentDampingOption(Enum):
    '''ComponentDampingOption

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _COMPONENT_DAMPING_OPTION

    __hash__ = None

    LOAD_CASE_GLOBAL_DAMPING = 0
    SPECIFIED = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


ComponentDampingOption.__setattr__ = __enum_setattr
ComponentDampingOption.__delattr__ = __enum_delattr



'''_7109.py

BoltCompoundAdvancedSystemDeflection
'''


from typing import List

from mastapy.system_model.part_model import _2151
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _6976
from mastapy.system_model.analyses_and_results.advanced_system_deflections.compound import _7115
from mastapy._internal.python_net import python_net_import

_BOLT_COMPOUND_ADVANCED_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections.Compound', 'BoltCompoundAdvancedSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('BoltCompoundAdvancedSystemDeflection',)


class BoltCompoundAdvancedSystemDeflection(_7115.ComponentCompoundAdvancedSystemDeflection):
    '''BoltCompoundAdvancedSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _BOLT_COMPOUND_ADVANCED_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BoltCompoundAdvancedSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2151.Bolt':
        '''Bolt: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2151.Bolt)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_6976.BoltAdvancedSystemDeflection]':
        '''List[BoltAdvancedSystemDeflection]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_6976.BoltAdvancedSystemDeflection))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_6976.BoltAdvancedSystemDeflection]':
        '''List[BoltAdvancedSystemDeflection]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_6976.BoltAdvancedSystemDeflection))
        return value



'''_1172.py

CustomSplineJointDesign
'''


from mastapy._internal import constructor
from mastapy.detailed_rigid_connectors.splines import _1197
from mastapy._internal.python_net import python_net_import

_CUSTOM_SPLINE_JOINT_DESIGN = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.Splines', 'CustomSplineJointDesign')


__docformat__ = 'restructuredtext en'
__all__ = ('CustomSplineJointDesign',)


class CustomSplineJointDesign(_1197.SplineJointDesign):
    '''CustomSplineJointDesign

    This is a mastapy class.
    '''

    TYPE = _CUSTOM_SPLINE_JOINT_DESIGN

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CustomSplineJointDesign.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def pressure_angle(self) -> 'float':
        '''float: 'PressureAngle' is the original name of this property.'''

        return self.wrapped.PressureAngle

    @pressure_angle.setter
    def pressure_angle(self, value: 'float'):
        self.wrapped.PressureAngle = float(value) if value else 0.0



'''_6503.py

BeltDriveLoadCase
'''


from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor
from mastapy.system_model.part_model.couplings import _2283, _2293
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.static_loads import _6637
from mastapy._internal.python_net import python_net_import

_BELT_DRIVE_LOAD_CASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'BeltDriveLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('BeltDriveLoadCase',)


class BeltDriveLoadCase(_6637.SpecialisedAssemblyLoadCase):
    '''BeltDriveLoadCase

    This is a mastapy class.
    '''

    TYPE = _BELT_DRIVE_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BeltDriveLoadCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def pre_tension(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'PreTension' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.PreTension) if self.wrapped.PreTension else None

    @pre_tension.setter
    def pre_tension(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.PreTension = value

    @property
    def assembly_design(self) -> '_2283.BeltDrive':
        '''BeltDrive: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2283.BeltDrive.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to BeltDrive. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None



'''_5668.py

CouplingConnectionHarmonicAnalysis
'''


from mastapy.system_model.connections_and_sockets.couplings import (
    _2055, _2051, _2053, _2057,
    _2059, _2061
)
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.system_deflections import (
    _2431, _2413, _2419, _2488,
    _2512, _2530
)
from mastapy.system_model.analyses_and_results.harmonic_analyses import _5719
from mastapy._internal.python_net import python_net_import

_COUPLING_CONNECTION_HARMONIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses', 'CouplingConnectionHarmonicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('CouplingConnectionHarmonicAnalysis',)


class CouplingConnectionHarmonicAnalysis(_5719.InterMountableComponentConnectionHarmonicAnalysis):
    '''CouplingConnectionHarmonicAnalysis

    This is a mastapy class.
    '''

    TYPE = _COUPLING_CONNECTION_HARMONIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CouplingConnectionHarmonicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_2055.CouplingConnection':
        '''CouplingConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2055.CouplingConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to CouplingConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_clutch_connection(self) -> '_2051.ClutchConnection':
        '''ClutchConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2051.ClutchConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ClutchConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_concept_coupling_connection(self) -> '_2053.ConceptCouplingConnection':
        '''ConceptCouplingConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2053.ConceptCouplingConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ConceptCouplingConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_part_to_part_shear_coupling_connection(self) -> '_2057.PartToPartShearCouplingConnection':
        '''PartToPartShearCouplingConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2057.PartToPartShearCouplingConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to PartToPartShearCouplingConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_spring_damper_connection(self) -> '_2059.SpringDamperConnection':
        '''SpringDamperConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2059.SpringDamperConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to SpringDamperConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_torque_converter_connection(self) -> '_2061.TorqueConverterConnection':
        '''TorqueConverterConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2061.TorqueConverterConnection.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to TorqueConverterConnection. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ConnectionDesign.__class__)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def system_deflection_results(self) -> '_2431.CouplingConnectionSystemDeflection':
        '''CouplingConnectionSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2431.CouplingConnectionSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to CouplingConnectionSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new_override(self.wrapped.SystemDeflectionResults.__class__)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_clutch_connection_system_deflection(self) -> '_2413.ClutchConnectionSystemDeflection':
        '''ClutchConnectionSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2413.ClutchConnectionSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to ClutchConnectionSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new_override(self.wrapped.SystemDeflectionResults.__class__)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_concept_coupling_connection_system_deflection(self) -> '_2419.ConceptCouplingConnectionSystemDeflection':
        '''ConceptCouplingConnectionSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2419.ConceptCouplingConnectionSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to ConceptCouplingConnectionSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new_override(self.wrapped.SystemDeflectionResults.__class__)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_part_to_part_shear_coupling_connection_system_deflection(self) -> '_2488.PartToPartShearCouplingConnectionSystemDeflection':
        '''PartToPartShearCouplingConnectionSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2488.PartToPartShearCouplingConnectionSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to PartToPartShearCouplingConnectionSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new_override(self.wrapped.SystemDeflectionResults.__class__)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_spring_damper_connection_system_deflection(self) -> '_2512.SpringDamperConnectionSystemDeflection':
        '''SpringDamperConnectionSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2512.SpringDamperConnectionSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to SpringDamperConnectionSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new_override(self.wrapped.SystemDeflectionResults.__class__)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_torque_converter_connection_system_deflection(self) -> '_2530.TorqueConverterConnectionSystemDeflection':
        '''TorqueConverterConnectionSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2530.TorqueConverterConnectionSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to TorqueConverterConnectionSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new_override(self.wrapped.SystemDeflectionResults.__class__)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None



'''_678.py

CylindricalGearGrindingWorm
'''


from mastapy._internal import constructor
from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _698, _700, _695
from mastapy._internal.cast_exception import CastException
from mastapy.gears.manufacturing.cylindrical.cutters import _682
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_GRINDING_WORM = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.Cutters', 'CylindricalGearGrindingWorm')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearGrindingWorm',)


class CylindricalGearGrindingWorm(_682.CylindricalGearRackDesign):
    '''CylindricalGearGrindingWorm

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_GRINDING_WORM

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearGrindingWorm.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def flat_tip_width(self) -> 'float':
        '''float: 'FlatTipWidth' is the original name of this property.'''

        return self.wrapped.FlatTipWidth

    @flat_tip_width.setter
    def flat_tip_width(self, value: 'float'):
        self.wrapped.FlatTipWidth = float(value) if value else 0.0

    @property
    def edge_height(self) -> 'float':
        '''float: 'EdgeHeight' is the original name of this property.'''

        return self.wrapped.EdgeHeight

    @edge_height.setter
    def edge_height(self, value: 'float'):
        self.wrapped.EdgeHeight = float(value) if value else 0.0

    @property
    def has_tolerances(self) -> 'bool':
        '''bool: 'HasTolerances' is the original name of this property.'''

        return self.wrapped.HasTolerances

    @has_tolerances.setter
    def has_tolerances(self, value: 'bool'):
        self.wrapped.HasTolerances = bool(value) if value else False

    @property
    def nominal_worm_grinder_shape(self) -> '_698.CylindricalGearWormGrinderShape':
        '''CylindricalGearWormGrinderShape: 'NominalWormGrinderShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_698.CylindricalGearWormGrinderShape)(self.wrapped.NominalWormGrinderShape) if self.wrapped.NominalWormGrinderShape else None

    @property
    def nominal_rack_shape(self) -> '_700.RackShape':
        '''RackShape: 'NominalRackShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _700.RackShape.TYPE not in self.wrapped.NominalRackShape.__class__.__mro__:
            raise CastException('Failed to cast nominal_rack_shape to RackShape. Expected: {}.'.format(self.wrapped.NominalRackShape.__class__.__qualname__))

        return constructor.new_override(self.wrapped.NominalRackShape.__class__)(self.wrapped.NominalRackShape) if self.wrapped.NominalRackShape else None

    @property
    def nominal_rack_shape_of_type_cylindrical_gear_hob_shape(self) -> '_695.CylindricalGearHobShape':
        '''CylindricalGearHobShape: 'NominalRackShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _695.CylindricalGearHobShape.TYPE not in self.wrapped.NominalRackShape.__class__.__mro__:
            raise CastException('Failed to cast nominal_rack_shape to CylindricalGearHobShape. Expected: {}.'.format(self.wrapped.NominalRackShape.__class__.__qualname__))

        return constructor.new_override(self.wrapped.NominalRackShape.__class__)(self.wrapped.NominalRackShape) if self.wrapped.NominalRackShape else None

    @property
    def nominal_rack_shape_of_type_cylindrical_gear_worm_grinder_shape(self) -> '_698.CylindricalGearWormGrinderShape':
        '''CylindricalGearWormGrinderShape: 'NominalRackShape' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _698.CylindricalGearWormGrinderShape.TYPE not in self.wrapped.NominalRackShape.__class__.__mro__:
            raise CastException('Failed to cast nominal_rack_shape to CylindricalGearWormGrinderShape. Expected: {}.'.format(self.wrapped.NominalRackShape.__class__.__qualname__))

        return constructor.new_override(self.wrapped.NominalRackShape.__class__)(self.wrapped.NominalRackShape) if self.wrapped.NominalRackShape else None



'''_7228.py

FEAnalysis
'''


from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.analysis_cases import _7234
from mastapy._internal.python_net import python_net_import

_FE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AnalysisCases', 'FEAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('FEAnalysis',)


class FEAnalysis(_7234.StaticLoadAnalysisCase):
    '''FEAnalysis

    This is a mastapy class.
    '''

    TYPE = _FE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FEAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def stiffness_with_respect_to_input_power_load(self) -> 'float':
        '''float: 'StiffnessWithRespectToInputPowerLoad' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StiffnessWithRespectToInputPowerLoad

    @property
    def torque_ratio_to_output(self) -> 'float':
        '''float: 'TorqueRatioToOutput' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TorqueRatioToOutput

    @property
    def torque_at_zero_displacement_for_input_power_load(self) -> 'float':
        '''float: 'TorqueAtZeroDisplacementForInputPowerLoad' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TorqueAtZeroDisplacementForInputPowerLoad



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6356 import AbstractAssemblyCompoundCriticalSpeedAnalysis
    from ._6357 import AbstractShaftCompoundCriticalSpeedAnalysis
    from ._6358 import AbstractShaftOrHousingCompoundCriticalSpeedAnalysis
    from ._6359 import AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6360 import AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis
    from ._6361 import AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6362 import AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6363 import AssemblyCompoundCriticalSpeedAnalysis
    from ._6364 import BearingCompoundCriticalSpeedAnalysis
    from ._6365 import BeltConnectionCompoundCriticalSpeedAnalysis
    from ._6366 import BeltDriveCompoundCriticalSpeedAnalysis
    from ._6367 import BevelDifferentialGearCompoundCriticalSpeedAnalysis
    from ._6368 import BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis
    from ._6369 import BevelDifferentialGearSetCompoundCriticalSpeedAnalysis
    from ._6370 import BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis
    from ._6371 import BevelDifferentialSunGearCompoundCriticalSpeedAnalysis
    from ._6372 import BevelGearCompoundCriticalSpeedAnalysis
    from ._6373 import BevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6374 import BevelGearSetCompoundCriticalSpeedAnalysis
    from ._6375 import BoltCompoundCriticalSpeedAnalysis
    from ._6376 import BoltedJointCompoundCriticalSpeedAnalysis
    from ._6377 import ClutchCompoundCriticalSpeedAnalysis
    from ._6378 import ClutchConnectionCompoundCriticalSpeedAnalysis
    from ._6379 import ClutchHalfCompoundCriticalSpeedAnalysis
    from ._6380 import CoaxialConnectionCompoundCriticalSpeedAnalysis
    from ._6381 import ComponentCompoundCriticalSpeedAnalysis
    from ._6382 import ConceptCouplingCompoundCriticalSpeedAnalysis
    from ._6383 import ConceptCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6384 import ConceptCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6385 import ConceptGearCompoundCriticalSpeedAnalysis
    from ._6386 import ConceptGearMeshCompoundCriticalSpeedAnalysis
    from ._6387 import ConceptGearSetCompoundCriticalSpeedAnalysis
    from ._6388 import ConicalGearCompoundCriticalSpeedAnalysis
    from ._6389 import ConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6390 import ConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6391 import ConnectionCompoundCriticalSpeedAnalysis
    from ._6392 import ConnectorCompoundCriticalSpeedAnalysis
    from ._6393 import CouplingCompoundCriticalSpeedAnalysis
    from ._6394 import CouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6395 import CouplingHalfCompoundCriticalSpeedAnalysis
    from ._6396 import CVTBeltConnectionCompoundCriticalSpeedAnalysis
    from ._6397 import CVTCompoundCriticalSpeedAnalysis
    from ._6398 import CVTPulleyCompoundCriticalSpeedAnalysis
    from ._6399 import CycloidalAssemblyCompoundCriticalSpeedAnalysis
    from ._6400 import CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6401 import CycloidalDiscCompoundCriticalSpeedAnalysis
    from ._6402 import CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6403 import CylindricalGearCompoundCriticalSpeedAnalysis
    from ._6404 import CylindricalGearMeshCompoundCriticalSpeedAnalysis
    from ._6405 import CylindricalGearSetCompoundCriticalSpeedAnalysis
    from ._6406 import CylindricalPlanetGearCompoundCriticalSpeedAnalysis
    from ._6407 import DatumCompoundCriticalSpeedAnalysis
    from ._6408 import ExternalCADModelCompoundCriticalSpeedAnalysis
    from ._6409 import FaceGearCompoundCriticalSpeedAnalysis
    from ._6410 import FaceGearMeshCompoundCriticalSpeedAnalysis
    from ._6411 import FaceGearSetCompoundCriticalSpeedAnalysis
    from ._6412 import FEPartCompoundCriticalSpeedAnalysis
    from ._6413 import FlexiblePinAssemblyCompoundCriticalSpeedAnalysis
    from ._6414 import GearCompoundCriticalSpeedAnalysis
    from ._6415 import GearMeshCompoundCriticalSpeedAnalysis
    from ._6416 import GearSetCompoundCriticalSpeedAnalysis
    from ._6417 import GuideDxfModelCompoundCriticalSpeedAnalysis
    from ._6418 import HypoidGearCompoundCriticalSpeedAnalysis
    from ._6419 import HypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6420 import HypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6421 import InterMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6422 import KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis
    from ._6423 import KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6424 import KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6425 import KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis
    from ._6426 import KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6427 import KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6428 import KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6429 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6430 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6431 import MassDiscCompoundCriticalSpeedAnalysis
    from ._6432 import MeasurementComponentCompoundCriticalSpeedAnalysis
    from ._6433 import MountableComponentCompoundCriticalSpeedAnalysis
    from ._6434 import OilSealCompoundCriticalSpeedAnalysis
    from ._6435 import PartCompoundCriticalSpeedAnalysis
    from ._6436 import PartToPartShearCouplingCompoundCriticalSpeedAnalysis
    from ._6437 import PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6438 import PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6439 import PlanetaryConnectionCompoundCriticalSpeedAnalysis
    from ._6440 import PlanetaryGearSetCompoundCriticalSpeedAnalysis
    from ._6441 import PlanetCarrierCompoundCriticalSpeedAnalysis
    from ._6442 import PointLoadCompoundCriticalSpeedAnalysis
    from ._6443 import PowerLoadCompoundCriticalSpeedAnalysis
    from ._6444 import PulleyCompoundCriticalSpeedAnalysis
    from ._6445 import RingPinsCompoundCriticalSpeedAnalysis
    from ._6446 import RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis
    from ._6447 import RollingRingAssemblyCompoundCriticalSpeedAnalysis
    from ._6448 import RollingRingCompoundCriticalSpeedAnalysis
    from ._6449 import RollingRingConnectionCompoundCriticalSpeedAnalysis
    from ._6450 import RootAssemblyCompoundCriticalSpeedAnalysis
    from ._6451 import ShaftCompoundCriticalSpeedAnalysis
    from ._6452 import ShaftHubConnectionCompoundCriticalSpeedAnalysis
    from ._6453 import ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6454 import SpecialisedAssemblyCompoundCriticalSpeedAnalysis
    from ._6455 import SpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6456 import SpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6457 import SpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6458 import SpringDamperCompoundCriticalSpeedAnalysis
    from ._6459 import SpringDamperConnectionCompoundCriticalSpeedAnalysis
    from ._6460 import SpringDamperHalfCompoundCriticalSpeedAnalysis
    from ._6461 import StraightBevelDiffGearCompoundCriticalSpeedAnalysis
    from ._6462 import StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis
    from ._6463 import StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis
    from ._6464 import StraightBevelGearCompoundCriticalSpeedAnalysis
    from ._6465 import StraightBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6466 import StraightBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6467 import StraightBevelPlanetGearCompoundCriticalSpeedAnalysis
    from ._6468 import StraightBevelSunGearCompoundCriticalSpeedAnalysis
    from ._6469 import SynchroniserCompoundCriticalSpeedAnalysis
    from ._6470 import SynchroniserHalfCompoundCriticalSpeedAnalysis
    from ._6471 import SynchroniserPartCompoundCriticalSpeedAnalysis
    from ._6472 import SynchroniserSleeveCompoundCriticalSpeedAnalysis
    from ._6473 import TorqueConverterCompoundCriticalSpeedAnalysis
    from ._6474 import TorqueConverterConnectionCompoundCriticalSpeedAnalysis
    from ._6475 import TorqueConverterPumpCompoundCriticalSpeedAnalysis
    from ._6476 import TorqueConverterTurbineCompoundCriticalSpeedAnalysis
    from ._6477 import UnbalancedMassCompoundCriticalSpeedAnalysis
    from ._6478 import VirtualComponentCompoundCriticalSpeedAnalysis
    from ._6479 import WormGearCompoundCriticalSpeedAnalysis
    from ._6480 import WormGearMeshCompoundCriticalSpeedAnalysis
    from ._6481 import WormGearSetCompoundCriticalSpeedAnalysis
    from ._6482 import ZerolBevelGearCompoundCriticalSpeedAnalysis
    from ._6483 import ZerolBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6484 import ZerolBevelGearSetCompoundCriticalSpeedAnalysis



'''_649.py

WormGrindingProcessPitchCalculation
'''


from mastapy._internal import constructor
from mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new import _613, _646
from mastapy._internal.python_net import python_net_import

_WORM_GRINDING_PROCESS_PITCH_CALCULATION = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew', 'WormGrindingProcessPitchCalculation')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGrindingProcessPitchCalculation',)


class WormGrindingProcessPitchCalculation(_646.WormGrindingProcessCalculation):
    '''WormGrindingProcessPitchCalculation

    This is a mastapy class.
    '''

    TYPE = _WORM_GRINDING_PROCESS_PITCH_CALCULATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WormGrindingProcessPitchCalculation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def result_z_plane(self) -> 'float':
        '''float: 'ResultZPlane' is the original name of this property.'''

        return self.wrapped.ResultZPlane

    @result_z_plane.setter
    def result_z_plane(self, value: 'float'):
        self.wrapped.ResultZPlane = float(value) if value else 0.0

    @property
    def right_flank(self) -> '_613.CalculatePitchDeviationAccuracy':
        '''CalculatePitchDeviationAccuracy: 'RightFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_613.CalculatePitchDeviationAccuracy)(self.wrapped.RightFlank) if self.wrapped.RightFlank else None

    @property
    def left_flank(self) -> '_613.CalculatePitchDeviationAccuracy':
        '''CalculatePitchDeviationAccuracy: 'LeftFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_613.CalculatePitchDeviationAccuracy)(self.wrapped.LeftFlank) if self.wrapped.LeftFlank else None
